==> dl.php?src=linea21_1_8.zip: linea21/languages/it/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\it
 * @author $Author$ - Alessandra Rossi & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "progetto";

/*	nommage des modules
 *  	*/
$lang['project']['name']="progetto";
$lang['project']['confirm_add'] = "Aggiunta di un progetto avvenuta con successo\n";
$lang['project']['confirm_mod'] = "Modifica del progetto avvenuta con successo\n";
$lang['project']['confirm_sup'] ="Eliminazione del progetto avvenuta con successo\n";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Aggiunta di un ".$lang['project']['name'];
$lang['project']['mod']= "Modifica di ".$lang['project']['name'];
$lang['project']['sup']= "Eliminazione di ".$lang['project']['name'];
$lang['project']['det']= "Dettagli di ".$lang['project']['name'];
$lang['project']['list']= "Consultazione di progetti";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']="Inserimento dei dati del nuovo ".$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nome ".$lang['project']['name'];
$lang['project']['goal']="goal(s)"; // @todo translation
$lang['project']['description']="descrizione";
$lang['project']['body']="contenuto";
$lang['project']['budget']="budget (in €)"; // @todo translation
$lang['project']['budget_comment']="budget - complement"; // @todo translation
$lang['project']['elected']="elected referent(s)"; // @todo translation
$lang['project']['manager']="manager(s)"; // @todo translation
$lang['project']['coordinator']="coordinator(s)"; // @todo translation
$lang['project']['team']="team project"; // @todo translation
$lang['project']['partners']="partners"; // @todo translation
$lang['project']['begin_date']="data di inizio del progetto";
$lang['project']['estimated_date']="stima della data di fine progetto";
$lang['project']['end_date']="fine effettiva";
$lang['project']['parent']="progetti affini";
$lang['project']['progression']="progression (%)"; // @todo translation
$lang['project']['sub-projects']="Sotto progetti";
$lang['project']['priority']="priorità";
$lang['project']['theme']='tema ';
$lang['project']['workshop']="gruppo di lavoro";
$lang['project']['comment']="comment"; // @todo translation
$lang['project']['sdi']="indicatori";
$lang['project']['scale']="scala";
$lang['project']['author']="autore";
$lang['project']['statut']='stato di pubblicazione';

$lang['project']['steering_title']='Sterring / animation'; // @todo translation
$lang['project']['calendar_title']='Calendar'; // @todo translation
$lang['project']['budget_title']='Budget'; // @todo translation

/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" ultime aggiunte effettuate";
$lang['project']['qb_titlemod']=" ultime modifiche effettuate";
$lang['project']['qb_titlesup']=" ultime eliminazioni effettuate";
$lang['project']['qb_titlepubli']=' ultime pubblicazioni effettuate';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Scegli nella lista qui sotto --";

$lang['project']['nb_total']='i progetti sono archiviati nel data base.';
$lang['project']['statut_filter']='Visualizza per status';
$lang['project']['all']='Visualizza la lista completa';
$lang['project']['noresult']='nessun progetto corrisponde ai criteri di selezione ';

/*	messages
 *  	*/
$lang['project']['no_name']="Devi tassativamente dare un nome al progetto";
$lang['project']['no_description']="Il progetto deve tassativamente avere una descrizione";
$lang['project']['no_body']="Il progetto deve tassativamente avere un contenuto";
$lang['project']['no_scale']='Il progetto deve tassativamente essere associato a una scala';
$lang['project']['no_priority']='Il progetto deve tassativamente essere associato a una priorità';
$lang['project']['progression_error']='Progression indicator muste take a value between 0 and 100.'; // @todo translation
$lang['project']['incorrect_user']='Given manager \'%s\' is unknown from the application'; // @todo translation
$lang['project']['incorrect_userperm']='Given manager  \'%s\' has not required permissions'; // @todo translation
$lang['project']['budget_integer']='Budget : an integer value is required'; // @todo translation
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';


/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Per aggiungere un progetto, devi inserire ciascuno dei suoi parametri nel modulo qui sotto";
$lang['project']['help_add2']="Dopo aver convalidato il modulo d'aggiunta, controlla i dati inseriti nel riepilogo";
$lang['project']['help_add3']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificarli";

$lang['project']['help_list1']="Per visualizzare un progetto nel dettaglio, clicca sul nome di quest'ultimo";
$lang['project']['help_list2']="Puoi eliminare un progetto cliccando sull'icona di eliminazione associata";
$lang['project']['help_list3']="Puoi modificare un progetto clicando sull'icona di modifica associata";
$lang['project']['help_list4']="Per aggiungere un progetto, clicca su 'aggiungere un progetto' ";
$lang['project']['help_list5']="Puoi effettuare una ricerca dei progetti in ogni momento cliccando su 'ricerca'";

$lang['project']['help_mod1']="Puoi modificare ciascuno dei parametri nel modulo qui sotto";
$lang['project']['help_mod2']="Dopo aver convalidato il modulo di modifica, controlla i dati inseriti nel riepilogo";
$lang['project']['help_mod3']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificare di nuovo i dati";

$lang['project']['help_det1']="Per visualizzare un progetto affini a quello in dettaglio, clicca sul nome di quest'ultimo";
$lang['project']['help_det2']="Puoi eliminare questo progetto cliccando sull'icona di eliminazione associata";
$lang['project']['help_det3']="Puoi modificare questo progetto cliccando sull'icona di modifica associata";

$lang['project']['help_sup1']="Attenzione, se questo progetto contiene dei sotto progetti, questi ultimi non saranno automaticamente cancellati";
?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/it/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\it
 * @author $Author$ - Alessandra Rossi & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "progetto";

/*	nommage des modules
 *  	*/
$lang['project']['name']="progetto";
$lang['project']['confirm_add'] = "Aggiunta di un progetto avvenuta con successo\n";
$lang['project']['confirm_mod'] = "Modifica del progetto avvenuta con successo\n";
$lang['project']['confirm_sup'] ="Eliminazione del progetto avvenuta con successo\n";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Aggiunta di un ".$lang['project']['name'];
$lang['project']['mod']= "Modifica di ".$lang['project']['name'];
$lang['project']['sup']= "Eliminazione di ".$lang['project']['name'];
$lang['project']['det']= "Dettagli di ".$lang['project']['name'];
$lang['project']['list']= "Consultazione di progetti";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']="Inserimento dei dati del nuovo ".$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nome ".$lang['project']['name'];
$lang['project']['goal']="goal(s)"; // @todo translation
$lang['project']['description']="descrizione";
$lang['project']['body']="contenuto";
$lang['project']['budget']="budget (in €)"; // @todo translation
$lang['project']['budget_comment']="budget - complement"; // @todo translation
$lang['project']['elected']="elected referent(s)"; // @todo translation
$lang['project']['manager']="manager(s)"; // @todo translation
$lang['project']['coordinator']="coordinator(s)"; // @todo translation
$lang['project']['team']="team project"; // @todo translation
$lang['project']['partners']="partners"; // @todo translation
$lang['project']['begin_date']="data di inizio del progetto";
$lang['project']['estimated_date']="stima della data di fine progetto";
$lang['project']['end_date']="fine effettiva";
$lang['project']['parent']="progetti affini";
$lang['project']['progression']="progression (%)"; // @todo translation
$lang['project']['sub-projects']="Sotto progetti";
$lang['project']['priority']="priorità";
$lang['project']['level']='livello';
$lang['project']['workshop']="gruppo di lavoro";
$lang['project']['comment']="comment"; // @todo translation
$lang['project']['sdi']="indicatori";
$lang['project']['scale']="scala";
$lang['project']['author']="autore";
$lang['project']['statut']='stato di pubblicazione';
$lang['project']['add_indicator']="add an indicator"; // @todo translation
$lang['project']['add_indicator_value']="enter an indicator value"; // @todo translation
$lang['project']['completion']="completion"; // @todo translation
$lang['project']['report']="Export / generate report"; // @todo translation
$lang['project']['steering_title']='Sterring / animation'; // @todo translation
$lang['project']['calendar_title']='Calendar'; // @todo translation
$lang['project']['budget_title']='Budget'; // @todo translation
$lang['project']['finalities']='Finalities'; // @todo translation

// views
$lang['project']['level_view']='Ordered by levels'; // @todo translation
$lang['project']['flat_view']='Flat view'; // @todo translation
$lang['project']['finality_view']='Ordered by finality'; // @todo translation


/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" ultime aggiunte effettuate";
$lang['project']['qb_titlemod']=" ultime modifiche effettuate";
$lang['project']['qb_titlesup']=" ultime eliminazioni effettuate";
$lang['project']['qb_titlepubli']=' ultime pubblicazioni effettuate';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Scegli nella lista qui sotto --";

$lang['project']['nb_total']='i progetti sono archiviati nel data base.';
$lang['project']['statut_filter']='Visualizza per status';
$lang['project']['all']='Visualizza la lista completa';
$lang['project']['noresult']='nessun progetto corrisponde ai criteri di selezione ';
$lang['project']['session-stored']="%s projects are stored in session"; // @todo translation

/*	messages
 *  	*/
$lang['project']['no_name']="Devi tassativamente dare un nome al progetto";
$lang['project']['no_description']="Il progetto deve tassativamente avere una descrizione";
$lang['project']['no_body']="Il progetto deve tassativamente avere un contenuto";
$lang['project']['no_scale']='Il progetto deve tassativamente essere associato a una scala';
$lang['project']['no_level']='Il progetto deve tassativamente essere associato a un livello';
$lang['project']['no_priority']='Il progetto deve tassativamente essere associato a una priorità';
$lang['project']['progression_error']='Progression indicator muste take a value between 0 and 100.'; // @todo translation
$lang['project']['incorrect_user']='Given manager \'%s\' is unknown from the application'; // @todo translation
$lang['project']['incorrect_userperm']='Given manager  \'%s\' has not required permissions'; // @todo translation
$lang['project']['budget_integer']='Budget : an integer value is required'; // @todo translation
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';
$lang['project']['inconsistent_date']='Given dates seem to be inconsistent. Please, change them.'; // @todo translation

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Per aggiungere un progetto, devi inserire ciascuno dei suoi parametri nel modulo qui sotto";
$lang['project']['help_add2']="Dopo aver convalidato il modulo d'aggiunta, controlla i dati inseriti nel riepilogo";
$lang['project']['help_add3']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificarli";

$lang['project']['help_list1']="Per visualizzare un progetto nel dettaglio, clicca sul nome di quest'ultimo";
$lang['project']['help_list2']="Puoi eliminare un progetto cliccando sull'icona di eliminazione associata";
$lang['project']['help_list3']="Puoi modificare un progetto clicando sull'icona di modifica associata";
$lang['project']['help_list4']="Per aggiungere un progetto, clicca su 'aggiungere un progetto' ";
$lang['project']['help_list5']="Puoi effettuare una ricerca dei progetti in ogni momento cliccando su 'ricerca'";

$lang['project']['help_mod1']="Puoi modificare ciascuno dei parametri nel modulo qui sotto";
$lang['project']['help_mod2']="Dopo aver convalidato il modulo di modifica, controlla i dati inseriti nel riepilogo";
$lang['project']['help_mod3']="Se il riepilogo non ti soddisfa, puoi cliccare su 'modifica i parametri' per modificare di nuovo i dati";

$lang['project']['help_det1']="Per visualizzare un progetto affini a quello in dettaglio, clicca sul nome di quest'ultimo";
$lang['project']['help_det2']="Puoi eliminare questo progetto cliccando sull'icona di eliminazione associata";
$lang['project']['help_det3']="Puoi modificare questo progetto cliccando sull'icona di modifica associata";

$lang['project']['help_sup1']="Attenzione, se questo progetto contiene dei sotto progetti, questi ultimi non saranno automaticamente cancellati";
?>
